core Package
============

:mod:`core` Package
-------------------

.. automodule:: cobra.core
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`ArrayBasedModel` Module
-----------------------------

.. automodule:: cobra.core.ArrayBasedModel
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`DictList` Module
----------------------

.. automodule:: cobra.core.DictList
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Formula` Module
---------------------

.. automodule:: cobra.core.Formula
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Gene` Module
------------------

.. automodule:: cobra.core.Gene
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Metabolite` Module
------------------------

.. automodule:: cobra.core.Metabolite
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Model` Module
-------------------

.. automodule:: cobra.core.Model
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Object` Module
--------------------

.. automodule:: cobra.core.Object
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Reaction` Module
----------------------

.. automodule:: cobra.core.Reaction
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`Solution` Module
----------------------

.. automodule:: cobra.core.Solution
    :members:
    :undoc-members:
    :show-inheritance:

